Crate scx_p2dq

Crate scx_p2dq 

Re-exports

pub use bpf_skel::types;

Modules

bpf_intf
bpf_skel
energy

Macros

init_open_skel
init_skel

Structs

HardwareProfile
NR_CPU_IDS
The maximum possible number of CPU IDs in the system. As mentioned above, this is different than the number of possible CPUs on the system (though very seldom is). This number may differ from the number of possible CPUs on the system when e.g. there are fully disabled CPUs in the middle of the range of possible CPUs (i.e. CPUs that may not be onlined).
SchedulerOpts
TOPO

Enums

CoreType
LbMode
SchedMode

Functions

dsq_slice_ns